"use strict";
// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var application_1 = require("@jupyterlab/application");
var apputils_1 = require("@jupyterlab/apputils");
var coreutils_1 = require("@phosphor/coreutils");
var widgets_1 = require("@phosphor/widgets");
require("../style/index.css");
/**
 * The command IDs used by the FAQ plugin.
 */
var CommandIDs;
(function (CommandIDs) {
    CommandIDs.open = 'faq-jupyterlab:open';
})(CommandIDs || (CommandIDs = {}));
/**
 * The FAQ page extension.
 */
var plugin = {
    activate: activate,
    id: '@jupyterlab/faq-extension:plugin',
    requires: [apputils_1.ICommandPalette, application_1.ILayoutRestorer],
    autoStart: true
};
/**
 * Export the plugin as default.
 */
exports.default = plugin;
/* tslint:disable */
/**
 * The faq page source.
 */
var SOURCE = require('../faq.md');
/* tslint:enable */
/**
 * A widget which is an faq viewer.
 */
var FAQWidget = (function (_super) {
    __extends(FAQWidget, _super);
    /**
     * Construct a new `AppWidget`.
     */
    function FAQWidget(content) {
        var _this = _super.call(this) || this;
        _this.addClass('jp-FAQ');
        _this.title.closable = true;
        _this.node.tabIndex = -1;
        _this.id = 'faq';
        _this.title.label = 'FAQ';
        var toolbar = new widgets_1.Widget();
        toolbar.addClass('jp-FAQ-toolbar');
        var layout = _this.layout = new widgets_1.PanelLayout();
        layout.addWidget(toolbar);
        layout.addWidget(content);
        return _this;
    }
    /**
     * Handle `close-request` events for the widget.
     */
    FAQWidget.prototype.onCloseRequest = function (message) {
        this.dispose();
    };
    /**
     * Handle `activate-request` events for the widget.
     */
    FAQWidget.prototype.onActivateRequest = function (message) {
        this.node.focus();
    };
    return FAQWidget;
}(widgets_1.Widget));
/**
 * Activate the FAQ plugin.
 */
function activate(app, palette, restorer) {
    var category = 'Help';
    var command = CommandIDs.open;
    var commands = app.commands, shell = app.shell, rendermime = app.rendermime;
    var tracker = new apputils_1.InstanceTracker({ namespace: 'faq' });
    // Handle state restoration.
    restorer.restore(tracker, {
        command: command,
        args: function () { return coreutils_1.JSONExt.emptyObject; },
        name: function () { return 'faq'; }
    });
    var createWidget = function () {
        var content = rendermime.createRenderer('text/markdown');
        var model = rendermime.createModel({
            data: { 'text/markdown': SOURCE }
        });
        content.renderModel(model);
        content.addClass('jp-FAQ-content');
        return new FAQWidget(content);
    };
    var widget;
    commands.addCommand(command, {
        label: 'Open FAQ',
        execute: function () {
            if (!widget || widget.isDisposed) {
                widget = createWidget();
            }
            if (!tracker.has(widget)) {
                tracker.add(widget);
                shell.addToMainArea(widget);
            }
            shell.activateById(widget.id);
        }
    });
    palette.addItem({ command: command, category: category });
}
//# sourceMappingURL=index.js.map